# GetPaymentTransactionLogResponseGatewayTransactionType

The type of the transaction, either making a payment, or canceling a payment.  

## Enum

* `AUTHORIZATION` (value: `'Authorization'`)

* `SALE` (value: `'Sale'`)

* `VOID` (value: `'Void'`)

* `INQUIRY` (value: `'Inquiry'`)

* `VOIDAUTH` (value: `'VoidAuth'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


